@@ -100,7 +100,6 @@ const Application = new Lang.Class({
         this.minersRunning = [];
         this._activationTimestamp = Gdk.CURRENT_TIME;
         this._extractPriority = null;
-        this._searchProvider = null;
 
         this.isBooks = isBooks;
 
@@ -121,6 +120,10 @@ const Application = new Lang.Class({
 
         this.add_main_option('version', 'v'.charCodeAt(0), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
                              _("Show the version of the program"), null);
+
+        this._searchProvider = new ShellSearchProvider.ShellSearchProvider();
+        this._searchProvider.connect('activate-result', Lang.bind(this, this._onActivateResult));
+        this._searchProvider.connect('launch-search', Lang.bind(this, this._onLaunchSearch));
     },
 
     _initGettingStarted: function() {
@@ -153,7 +156,7 @@ const Application = new Lang.Class({
                                 try {
                                     manager.index_file_finish(res);
                                 } catch (e) {
-                                    log('Error indexing the getting started PDF: ' + e.message);
+                                    logError(e, 'Error indexing the getting started PDF');
                                 }
                             });
                     } catch (e) {
@@ -165,23 +168,6 @@ const Application = new Lang.Class({
         checkNextFile.apply(this);
     },
 
-    _fullscreenCreateHook: function(action) {
-        modeController.connect('can-fullscreen-changed', Lang.bind(this,
-            function() {
-                let canFullscreen = modeController.getCanFullscreen();
-                action.set_enabled(canFullscreen);
-            }));
-    },
-
-    _viewAsCreateHook: function(action) {
-        settings.connect('changed::view-as', Lang.bind(this,
-            function() {
-                let state = settings.get_value('view-as');
-                if (state.get_string()[0] != action.state.get_string()[0])
-                    action.change_state(state);
-            }));
-    },
-
     _nightModeCreateHook: function(action) {
         settings.connect('changed::night-mode', Lang.bind(this,
             function() {
@@ -198,15 +184,6 @@ const Application = new Lang.Class({
         gtkSettings.gtk_application_prefer_dark_theme = state.get_boolean();
     },
 
-    _sortByCreateHook: function(action) {
-        settings.connect('changed::sort-by', Lang.bind(this,
-            function() {
-                let state = settings.get_value('sort-by');
-                if (state.get_string()[0] != action.state.get_string()[0])
-                    action.change_state(state);
-            }));
-    },
-
     _onActionQuit: function() {
         this._mainWindow.destroy();
     },
@@ -221,7 +198,7 @@ const Application = new Lang.Class({
                          'help:gnome-documents',
                          Gtk.get_current_event_time());
         } catch (e) {
-            log('Unable to display help: ' + e.message);
+            logError(e, 'Unable to display help');
         }
     },
 
@@ -230,45 +207,6 @@ const Application = new Lang.Class({
         settings.set_value('night-mode', GLib.Variant.new('b', !state.get_boolean()));
     },
 
-    _onActionFullscreen: function(action) {
-        let state = action.get_state();
-        let newState = !state.get_boolean();
-        action.change_state(GLib.Variant.new('b', newState));
-        modeController.setFullscreen(newState);
-    },
-
-    _onActionViewAs: function(action, parameter) {
-        if (parameter.get_string()[0] != action.state.get_string()[0])
-            settings.set_value('view-as', parameter);
-    },
-
-    _onActionSortBy: function(action, parameter) {
-        if (parameter.get_string()[0] != action.state.get_string()[0])
-            settings.set_value('sort-by', parameter);
-    },
-
-    _connectActionsToMode: function() {
-        this._actionEntries.forEach(Lang.bind(this,
-            function(actionEntry) {
-                if (actionEntry.window_mode) {
-                    modeController.connect('window-mode-changed', Lang.bind(this,
-                        function() {
-                            let mode = modeController.getWindowMode();
-                            let action = this.lookup_action(actionEntry.name);
-                            action.set_enabled(mode == actionEntry.window_mode);
-                        }));
-                } else if (actionEntry.window_modes) {
-                    modeController.connect('window-mode-changed', Lang.bind(this,
-                        function() {
-                            let mode = modeController.getWindowMode();
-                            let enable = actionEntry.window_modes.indexOf(mode) != -1;
-                            let action = this.lookup_action(actionEntry.name);
-                            action.set_enabled(enable);
-                        }));
-                }
-            }));
-    },
-
     _createMiners: function(callback) {
         let count = 3;
 
@@ -316,7 +254,7 @@ const Application = new Lang.Class({
 
                 if (error) {
                     if (!error.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.CANCELLED))
-                        log('Error updating the cache: ' + error.toString());
+                        logError(error, 'Error updating the cache');
 
                     return;
                 }
@@ -336,7 +274,7 @@ const Application = new Lang.Class({
                 // startup a refresh of the gdocs cache
                 this._refreshMinerNow(this.gdataMiner);
             } catch (e) {
-                log('Unable to start GData miner: ' + e.message);
+                logError(e, 'Unable to start GData miner');
             }
         }
 
@@ -345,7 +283,7 @@ const Application = new Lang.Class({
                 // startup a refresh of the owncloud cache
                 this._refreshMinerNow(this.owncloudMiner);
             } catch (e) {
-                log('Unable to start Owncloud miner: ' + e.message);
+                logError(e, 'Unable to start Owncloud miner');
             }
         }
 
@@ -354,7 +292,7 @@ const Application = new Lang.Class({
                 // startup a refresh of the skydrive cache
                 this._refreshMinerNow(this.zpjMiner);
             } catch (e) {
-                log('Unable to start Zpj miner: ' + e.message);
+                logError(e, 'Unable to start Zpj miner');
             }
         }
     },
@@ -430,7 +368,7 @@ const Application = new Lang.Class({
         try {
             connection = Tracker.SparqlConnection.get(null);
         } catch (e) {
-            log('Unable to connect to the tracker database: ' + e.toString());
+            logError(e, 'Unable to connect to the tracker database');
             return;
         }
 
@@ -438,7 +376,7 @@ const Application = new Lang.Class({
             try {
                 goaClient = Goa.Client.new_sync(null);
             } catch (e) {
-                log('Unable to create the GOA client: ' + e.toString());
+                logError(e, 'Unable to create the GOA client');
                 return;
             }
         }
@@ -459,7 +397,7 @@ const Application = new Lang.Class({
         trackerSearchController = new TrackerController.TrackerSearchController();
         selectionController = new Selections.SelectionController();
 
-        this._actionEntries = [
+        let actionEntries = [
             { name: 'quit',
               callback: Lang.bind(this, this._onActionQuit),
               accels: ['<Primary>q'] },
@@ -468,26 +406,16 @@ const Application = new Lang.Class({
             { name: 'help',
               callback: Lang.bind(this, this._onActionHelp),
               accels: ['F1'] },
-            { name: 'fullscreen',
-              callback: Lang.bind(this, this._onActionFullscreen),
-              state: GLib.Variant.new('b', false),
-              create_hook: Lang.bind(this, this._fullscreenCreateHook),
-              accels: ['F11'],
-              window_mode: WindowMode.WindowMode.PREVIEW_EV },
             { name: 'night-mode',
               callback: Lang.bind(this, this._onActionNightMode),
               create_hook: Lang.bind(this, this._nightModeCreateHook),
               state: settings.get_value('night-mode') },
-            { name: 'search',
-              callback: Utils.actionToggleCallback,
-              state: GLib.Variant.new('b', false),
-              accels: ['<Primary>f'] }
         ];
 
         if (!this.isBooks)
             this._initGettingStarted();
 
-        Utils.populateActionGroup(this, this._actionEntries, 'app');
+        Utils.populateActionGroup(this, actionEntries, 'app');
     },
 
     _createWindow: function() {
@@ -495,7 +423,6 @@ const Application = new Lang.Class({
             return;
 
         notificationManager = new Notifications.NotificationManager();
-        this._connectActionsToMode();
         this._mainWindow = new MainWindow.MainWindow(this);
         this._mainWindow.connect('destroy', Lang.bind(this, this._onWindowDestroy));
 
@@ -503,7 +430,7 @@ const Application = new Lang.Class({
             this._extractPriority = TrackerExtractPriority();
             this._extractPriority.SetRdfTypesRemote(['nfo:Document']);
         } catch (e) {
-            log('Unable to connect to the tracker extractor: ' + e.toString());
+            logError(e, 'Unable to connect to the tracker extractor');
         }
 
         // start miners
@@ -513,28 +440,12 @@ const Application = new Lang.Class({
     vfunc_dbus_register: function(connection, path) {
         this.parent(connection, path);
 
-        if (this._searchProvider != null)
-            throw(new Error('ShellSearchProvider already instantiated - dbus_register called twice?'));
-
-        this._searchProvider = new ShellSearchProvider.ShellSearchProvider();
-        this._searchProvider.connect('activate-result', Lang.bind(this, this._onActivateResult));
-        this._searchProvider.connect('launch-search', Lang.bind(this, this._onLaunchSearch));
-
-        try {
-            this._searchProvider.export(connection);
-        } catch(e) {
-            this._searchProvider = null;
-            throw(e);
-        }
-
+        this._searchProvider.export(connection);
         return true;
     },
 
     vfunc_dbus_unregister: function(connection, path) {
-        if (this._searchProvider != null) {
-            this._searchProvider.unexport(connection);
-            this._searchProvider = null;
-        }
+        this._searchProvider.unexport(connection);
 
         this.parent(connection, path);
     },
@@ -596,7 +507,6 @@ const Application = new Lang.Class({
 
     _onActivateResult: function(provider, urn, terms, timestamp) {
         this._createWindow();
-        modeController.setWindowMode(WindowMode.WindowMode.PREVIEW_EV);
 
         let doc = documentManager.getItemById(urn);
         if (doc) {
@@ -621,14 +531,10 @@ const Application = new Lang.Class({
             // forward the search terms next time we enter the overview
             let modeChangeId = modeController.connect('window-mode-changed', Lang.bind(this,
                 function(object, newMode) {
-                    if (newMode == WindowMode.WindowMode.EDIT
-                        || newMode == WindowMode.WindowMode.PREVIEW_EV)
-                        return;
-
-                    modeController.disconnect(modeChangeId);
-
-                    searchController.setString(terms.join(' '));
-                    this.change_action_state('search', GLib.Variant.new('b', true));
+                    if (newMode == WindowMode.WindowMode.DOCUMENTS) {
+                        modeController.disconnect(modeChangeId);
+                        searchController.setString(terms.join(' '));
+                    }
                 }));
         }
     },
@@ -637,7 +543,6 @@ const Application = new Lang.Class({
         this._createWindow();
         modeController.setWindowMode(WindowMode.WindowMode.DOCUMENTS);
         searchController.setString(terms.join(' '));
-        this.change_action_state('search', GLib.Variant.new('b', true));
 
         this._activationTimestamp = timestamp;
         this.activate();
