@@ -50,6 +50,8 @@ const Preview = new Lang.Class({
         this.view.show();
         this.set_visible_child_full('view', Gtk.StackTransitionType.NONE);
 
+        this.toolbar = this.createToolbar();
+
         this.contextMenu = this.createContextMenu();
         if (this.contextMenu)
             this.contextMenu.attach_to_widget(this.view, null);
@@ -69,6 +71,12 @@ const Preview = new Lang.Class({
     },
 
     _getDefaultActions: function() {
+        let backAccels = ['Back'];
+        if (this.get_direction() == Gtk.TextDirection.LTR)
+            backAccels.push('<Alt>Left');
+        else
+            backAccels.push('<Alt>Right');
+
         return [
             { name: 'gear-menu',
               callback: Utils.actionToggleCallback,
@@ -77,7 +85,16 @@ const Preview = new Lang.Class({
             { name: 'properties',
               callback: Lang.bind(this, this._properties) },
             { name: 'open-current',
-              callback: Lang.bind(this, this._openCurrent) }
+              callback: Lang.bind(this, this._openCurrent) },
+            { name: 'prev-page',
+              callback: Lang.bind(this, this.goPrev),
+              accels: ['<Primary>Page_Up', 'Left'] },
+            { name: 'next-page',
+              callback: Lang.bind(this, this.goNext),
+              accels: ['<Primary>Page_Down', 'Right'] },
+            { name: 'go-back',
+              callback: Lang.bind(this, this.goBack),
+              accels: backAccels }
         ];
     },
 
@@ -200,6 +217,11 @@ const Preview = new Lang.Class({
         return this.actionGroup.lookup_action(name);
     },
 
+    goBack: function() {
+        Application.documentManager.setActiveItem(null);
+        Application.modeController.goBack();
+    },
+
     goPrev: function() {
         throw (new Error('Not implemented'));
     },
@@ -228,7 +250,7 @@ const Preview = new Lang.Class({
         return this._lastSearch;
     },
 
-    get canFind() {
+    get fullscreen() {
         return false;
     },
 
@@ -238,10 +260,6 @@ const Preview = new Lang.Class({
 
     findNext: function() {
         throw (new Error('Not implemented'));
-    },
-
-    scroll: function(direction) {
-        throw (new Error('Not implemented'));
     }
 });
 
@@ -256,12 +274,7 @@ const PreviewToolbar = new Lang.Class({
         this.toolbar.set_show_close_button(true);
 
         // back button, on the left of the toolbar
-        let backButton = this.addBackButton();
-        backButton.connect('clicked', Lang.bind(this,
-            function() {
-                Application.documentManager.setActiveItem(null);
-                Application.modeController.goBack();
-            }));
+        this.addBackButton();
 
         // menu button, on the right of the toolbar
         let menuButton = new Gtk.MenuButton({ image: new Gtk.Image ({ icon_name: 'open-menu-symbolic' }),
@@ -269,10 +282,6 @@ const PreviewToolbar = new Lang.Class({
                                               action_name: 'view.gear-menu' });
         this.toolbar.pack_end(menuButton);
 
-        // search button, on the right of the toolbar
-        if (this.preview.canFind)
-            this.addSearchButton();
-
         this.updateTitle();
         this.toolbar.show_all();
     },
@@ -514,6 +523,11 @@ const PreviewSearchbar = new Lang.Class({
         this.preview = preview;
 
         this.parent();
+
+        this.connect('notify::search-mode-enabled', Lang.bind(this, function() {
+            let action = this.preview.getAction('find');
+            action.change_state(GLib.Variant.new('b', this.search_mode_enabled));
+        }));
     },
 
     createSearchWidget: function() {
